# inquirer_console Changelog

本目录包含 inquirer_console 的所有版本发布说明。

## 发布历史

### 稳定版本

- [v1.0.0](./v1.0.0.md) - 2024-03-31 ([English](./v1.0.0.en.md))

### 预发布版本

暂无预发布版本。

---

changelog 目录使用多语言版本：
- 中文版使用直接的文件名，如 `v1.0.0.md`
- 英文版使用带 `.en` 后缀的文件名，如 `v1.0.0.en.md`

如需查看最新的开发进度，请访问我们的 [GitHub 仓库](https://github.com/Eusen/inquirer_console)。 